Natural Language Support (NLS)
==============================

These are inputs for language support using gettext.

 - Template file libbout.pot : Do not edit
   This is generated by extracting strings from the BOUT++ source.
 - Language files .po which are human-readable. These contain
   translations for particular languages, and can be edited.
 - Machine readable .mo files. These are created from the .po files.

Build all .mo files:

    make

Update the template (.pot) file:

    make libbout.pot

Start a new translation:

    make locale-XX

where XX is the language e.g. "de" for German, or a language_country code e.g. "de_DE".
Edit the .po file, translating or deleting new entries:
 * Make sure to set the charset (around line 16) to utf-8.
 * msgid is the original text. Write in msgstr the translated string.
 * You can reorder arguments using %n$s like this::
     msgid ""
     "Options: Setting a value from same source (%s) to new value '%s' - old value "
     "was '%s'."
     msgstr ""
     "Options: The Value %3$s is overwritten with %2$s from the same source (%1%s)"
There are also editors for editing .po files, e.g. poeditor.

Calling `make locale-XX` again will update the .po file.
